/**
 * @author 翁旺
 * @date 2018-09-19 16:01:40
 * @description 自动生成前端项目脚手架脚本
 * @email wengwang@cecdat.com
 * @copyright Copyright 2018 CEC(Fujian) Healthcare Big Data Operation Service Co., Ltd. All rights reserved.
 */
const commander = require('commander')
const pkg = require('./package.json')
const path = require('path')
const fs = require('fs-extra')
const spawn = require('cross-spawn')
const download = require('download-git-repo')
const log = require('./lib/log.js')

let projectName

// 使用master分支的zip
const zipURL = 'http://192.168.1.23:8888/cecdataFE/react-boilerplate/-/archive/master/react-boilerplate-master.zip'

new commander
  .Command(pkg.name)
  .version(pkg.version)
  .action(name => {
    projectName = name
  })
  .parse(process.argv)

if (!projectName) {
  log.error('必须填写项目名称,例如 create-tpl project')
  process.exit(1)
}

const npmCommond = 'npm'
const npmCommondArgs = ['install']

const gitCommond = 'git'
const gitCommondInit = ['init']

const appDir = path.resolve(projectName)

fs.ensureDirSync(path.resolve(projectName))
log.success(`创建 ${projectName} 文件夹成功`)

process.chdir(appDir)

spawn.sync(gitCommond, gitCommondInit, { stdio: 'inherit' })
log.success(`初始化 git 成功`)
log.tip(`请自行指定 git 远程地址，git remote add <git url>`)

download(`direct:${zipURL}`, appDir, function (err) {
  if (err) {
    log.error('下载模板出错 ...')
    return false
  }
  log.success(`生成模板文件成功`)

  log.warning(`正在安装依赖 ...`)
  spawn.sync(npmCommond, ['install', '-g', 'commitlint'], { stdio: 'inherit' })
  spawn.sync(npmCommond, npmCommondArgs, { stdio: 'inherit' })
  log.success(`安装依赖成功`)

  console.log('\n')

  log.success(`执行以下命令就能愉快的开始了：`)
  log.tip(`cd ./${projectName} && npm run dev`)
})
